package org.mathcs.ibookmark;

/**
 * Activity to edit a bookmark by editing its title and its address. Also provides
 * the opportunity to preview the address.
 * 
 * @author Bert Wachsmuth
 * @version 1.0 (10/2013)
 */
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

public class BookmarkItemEdit extends Activity
{
	private TextView urlField = null;
	private TextView titleField = null;
	
	private Button preview = null;
	private Button okay = null;
	
	private WebView web = null;
	private int selectedIndex = -1;
	
	private AlertDialog alert = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_bookmark_item);
		
		getActionBar().setDisplayHomeAsUpEnabled(true);
		setTitle("Add/Edit Bookmark");
		
		preview = (Button)this.findViewById(R.id.id_button_preview);
		okay = (Button)this.findViewById(R.id.id_button_okay_itemedit);

		urlField = (TextView) this.findViewById(R.id.id_input_url);
		titleField = (TextView)this.findViewById(R.id.id_input_title);
		
		selectedIndex = getIntent().getIntExtra(BookmarkActivity.KEY_INDEX, -1);
		if (selectedIndex >= 0)
		{
			String title = getIntent().getStringExtra(BookmarkActivity.KEY_TITLE);
			String url = getIntent().getStringExtra(BookmarkActivity.KEY_URL);
			titleField.setText(title);
			urlField.setText(url);
		}
		else
			urlField.setText("http://");

		web = (WebView)this.findViewById(R.id.id_webview_itemedit);

		web.getSettings().setJavaScriptEnabled(true);
		
		web.setWebChromeClient(new WebChromeClient()
			{
				public void onProgressChanged(WebView view, int progress)
				{
					// Activities and WebViews measure progress with different scales.
					// The progress meter will automatically disappear when we reach 100%
					setProgress(progress * 1000);
				}
			});
		
		web.setWebViewClient(new WebViewClient()
		{
			public void onReceivedError(WebView view, int errorCode, String description, String failingUrl)
			{
				Toast.makeText(BookmarkItemEdit.this, "Oh no! " + description, Toast.LENGTH_SHORT).show();
			}
		});
		
		preview.setOnClickListener(new View.OnClickListener()
			{
				@Override
				public void onClick(View v)
				{
					String url = urlField.getText().toString().trim();
					if ((url == null) || (url.equals("")) || (url.equals("http://")))
						showAlert("The web address is empty - can't preview.");
					else
						web.loadUrl(url);
						
				}
			});
		
		okay.setOnClickListener(new View.OnClickListener()
			{				
				@Override
				public void onClick(View v)
				{
					Intent data = new Intent();
					
					String title = titleField.getText().toString().trim();
					String url = urlField.getText().toString().trim();
					
					if ((title == null) || (title.equals("")))
						showAlert("The Title can not be empty.");
					else if ((url == null) || (url.equals("")) || (url.equals("http://")))
						showAlert("The Address can not be empty.");
					else
					{
						data.putExtra(BookmarkActivity.KEY_URL, url);
						data.putExtra(BookmarkActivity.KEY_TITLE, title);
						data.putExtra(BookmarkActivity.KEY_INDEX, selectedIndex);
						setResult(RESULT_OK, data);
						finish();
					}
				}
			});
	}
	
	private void showAlert(String msg)
	{
		if (alert == null)
		{
			AlertDialog.Builder builder = new AlertDialog.Builder(this);
			builder.setTitle("Warning");
			builder.setPositiveButton("Dismiss", null); 
			alert = builder.create();
		}
		alert.setMessage(msg);
		alert.show();
	}
}
