package org.mathcs.ibookmark;

/**
 * Minimal "web browser like" activity that shows a web page. Javascript is enabled
 * and links should be active within the activity.
 * 
 * @author Bert Wachsmuth
 * @version 1.0 (10/2013)
 */
import android.app.Activity;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.preference.PreferenceManager;
import android.view.Window;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.Toast;

public class UrlViewer extends Activity
{
	private WebView web;
	private String url;

	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		// Must call this before setting the content view!!!
		getWindow().requestFeature(Window.FEATURE_PROGRESS);
		
		web = new WebView(this);

		setContentView(web);

		getActionBar().setDisplayHomeAsUpEnabled(true);

		SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(this);
		boolean javascriptEnabled = prefs.getBoolean("javascriptPref", true);
		
		web.getSettings().setJavaScriptEnabled(javascriptEnabled);
		web.setWebChromeClient(new WebChromeClient()
			{
				public void onProgressChanged(WebView view, int progress)
				{
					// The progress meter will automatically disappear when we reach 100%
					setProgress(progress * 1000);
				}
			});
		
		web.setWebViewClient(new WebViewClient()
		{
			public void onReceivedError(WebView view, int errorCode, String description, String failingUrl)
			{
				Toast.makeText(UrlViewer.this, "Oh no! " + description, Toast.LENGTH_SHORT).show();
			}
		});

		url = getIntent().getStringExtra(BookmarkActivity.KEY_URL);

		setTitle(url);
		web.loadUrl(url);
	}
}
